"""Portfolio Manager specialist module."""

from examples.portfolio_analysis.specialists.portfolio.models import AllocationChange, PortfolioRecommendations
from examples.portfolio_analysis.specialists.portfolio.signature import PortfolioManagerSignature

__all__ = ["AllocationChange", "PortfolioManagerSignature", "PortfolioRecommendations"]
